import djclick as click
import djclick as click
from django_safe_settings.settings import DJANGO_SAFE_SETTINGS_CIPHER

@click.command()
@click.argument("plain_value", nargs=1, required=True)
def django_safe_settings_encrypt(plain_value):
    """Encrypt plain value and print out the result, so that you can copy it to your settings.py.
    """
    result = DJANGO_SAFE_SETTINGS_CIPHER.encrypt(plain_value)
    print("    plain value =", plain_value)
    print("encrypted value =", result)




import sys
import logging
import inspect
from pprint import pprint
from magic_import import get_caller_globals

from .settings import DJANGO_SAFE_SETTINGS_CIPHER

logger = logging.getLogger(__name__)



def fix_data(data):
    if isinstance(data, dict):
        for key in list(data.keys()):
            data[key] = fix_data(data[key])
    elif isinstance(data, list):
        for index in range(len(data)):
            data[index] = fix_data(data[index])
    elif isinstance(data, str):
        try:
            return DJANGO_SAFE_SETTINGS_CIPHER.decrypt(data)
        except:
            pass
    return data


def patch_all():
    frame = inspect.currentframe()
    globals = frame.f_back.f_globals
    fix_data(globals)



from fastutils import cipherutils

try:
    from django.conf import settings
    DJANGO_SAFE_SETTINGS_SECRET_KEY_PREFIX = getattr(settings, "DJANGO_SAFE_SETTINGS_SECRET_KEY_PREFIX", "DJANGO_SAFE_SETTINGS_SECRET_KEY:CFksLnnN2wtsCdcQNRUnyEoqzq01ri8G")
    DJANGO_SAFE_SETTINGS_SECRET_KEY = DJANGO_SAFE_SETTINGS_SECRET_KEY_PREFIX + getattr(settings, "DJANGO_SAFE_SETTINGS_SECRET_KEY", settings.SECRET_KEY)
    DJANGO_SAFE_SETTINGS_CIPHER = getattr(settings, "DJANGO_SAFE_SETTINGS_CIPHER", None)

except:
    settings = globals()
    DJANGO_SAFE_SETTINGS_SECRET_KEY_PREFIX = settings.get("DJANGO_SAFE_SETTINGS_SECRET_KEY_PREFIX", "DJANGO_SAFE_SETTINGS_SECRET_KEY:CFksLnnN2wtsCdcQNRUnyEoqzq01ri8G")
    DJANGO_SAFE_SETTINGS_SECRET_KEY = DJANGO_SAFE_SETTINGS_SECRET_KEY_PREFIX + settings.get("DJANGO_SAFE_SETTINGS_SECRET_KEY", settings["SECRET_KEY"])
    DJANGO_SAFE_SETTINGS_CIPHER = settings.get("DJANGO_SAFE_SETTINGS_CIPHER", None)

if not DJANGO_SAFE_SETTINGS_CIPHER:
    DJANGO_SAFE_SETTINGS_CIPHER = cipherutils.AesCipher(password=DJANGO_SAFE_SETTINGS_SECRET_KEY, result_encoder=cipherutils.HexlifyEncoder(), force_text=True)
